==> core-react-0.8.0.tgz: package/es/Modal/ModalContent.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import classlist from 'classlist';
import cx from 'classnames';

var ModalContent = /*#__PURE__*/function (_Component) {
  _inherits(ModalContent, _Component);

  function ModalContent(props) {
    var _this;

    _classCallCheck(this, ModalContent);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(ModalContent).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "handleModalClick", function (e) {
      if (e.target.className === "".concat("waui", "-modal__modal")) {
        if (!_this.props.lock) {
          _this.props.close();
        } else {
          var LOCK_CLASSNAME = "".concat("waui", "-modal__modal-dialog_lock");
          var END_EVENT = 'animationend';
          classlist(_this.modalNode).add(LOCK_CLASSNAME);

          var onAnimationEnd = function onAnimationEnd() {
            _this.modalNode.removeEventListener(END_EVENT, onAnimationEnd);

            classlist(_this.modalNode).remove(LOCK_CLASSNAME);
          };

          _this.modalNode.addEventListener(END_EVENT, onAnimationEnd);
        }
      }
    });

    _this.relativeValue = 0;
    return _this;
  }

  _createClass(ModalContent, [{
    key: "getChildContext",
    value: function getChildContext() {
      return {
        modalContent: this
      };
    }
  }, {
    key: "backUp",
    value: function backUp() {
      this.relativeValue += 20;
      this.transform();
      var modalContent = this.props.modal.context.modalContent;

      if (modalContent) {
        modalContent.backUp();
      }
    }
  }, {
    key: "goForward",
    value: function goForward() {
      this.relativeValue -= 20;
      this.transform();
      var modalContent = this.props.modal.context.modalContent;

      if (modalContent) {
        modalContent.goForward();
      }
    }
  }, {
    key: "transform",
    value: function transform() {
      this.modalNode.style.transform = "translateY(-".concat(this.relativeValue, "px)");
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props = this.props,
          children = _this$props.children,
          className = _this$props.className,
          lock = _this$props.lock,
          size = _this$props.size,
          zIndex = _this$props.zIndex,
          close = _this$props.close,
          modal = _this$props.modal,
          other = _objectWithoutProperties(_this$props, ["children", "className", "lock", "size", "zIndex", "close", "modal"]);

      return React.createElement("div", _extends({
        className: cx("".concat("waui", "-modal"), _defineProperty({}, "".concat("waui", "-modal_").concat(size), size), className)
      }, other), React.createElement("div", {
        className: "".concat("waui", "-modal__backdrop"),
        style: {
          zIndex: zIndex || 3000
        }
      }), React.createElement("div", {
        className: "".concat("waui", "-modal__modal"),
        style: {
          zIndex: zIndex || 3000
        },
        onClick: this.handleModalClick
      }, React.createElement("div", {
        className: "".concat("waui", "-modal__modal-dialog"),
        ref: function ref(node) {
          return _this2.modalNode = node;
        }
      }, React.createElement("div", {
        className: "".concat("waui", "-modal__modal-content")
      }, children), React.createElement("div", {
        className: "".concat("waui", "-modal__modal-close"),
        onClick: function onClick() {
          return close();
        }
      }))));
    }
  }]);

  return ModalContent;
}(Component);

ModalContent.childContextTypes = {
  modalContent: PropTypes.instanceOf(ModalContent)
};
ModalContent.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,
  lock: PropTypes.bool,
  size: PropTypes.string,
  zIndex: PropTypes.number,
  close: PropTypes.func,
  modal: PropTypes.object
};
export default ModalContent;

==> core-react-0.8.2.tgz: package/es/Modal/ModalContent.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import classlist from 'classlist';
import cx from 'classnames';

var ModalContent = /*#__PURE__*/function (_Component) {
  _inherits(ModalContent, _Component);

  function ModalContent(props) {
    var _this;

    _classCallCheck(this, ModalContent);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(ModalContent).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "handleModalClick", function (e) {
      if (e.target.className === "".concat("waui", "-modal__modal")) {
        if (!_this.props.lock) {
          _this.props.close();
        } else {
          var LOCK_CLASSNAME = "".concat("waui", "-modal__modal-dialog_lock");
          var END_EVENT = 'animationend';
          classlist(_this.modalNode).add(LOCK_CLASSNAME);

          var onAnimationEnd = function onAnimationEnd() {
            _this.modalNode.removeEventListener(END_EVENT, onAnimationEnd);

            classlist(_this.modalNode).remove(LOCK_CLASSNAME);
          };

          _this.modalNode.addEventListener(END_EVENT, onAnimationEnd);
        }
      }
    });

    _this.relativeValue = 0;
    return _this;
  }

  _createClass(ModalContent, [{
    key: "getChildContext",
    value: function getChildContext() {
      return {
        modalContent: this
      };
    }
  }, {
    key: "backUp",
    value: function backUp() {
      this.relativeValue += 20;
      this.transform();
      var modalContent = this.props.modal.context.modalContent;

      if (modalContent) {
        modalContent.backUp();
      }
    }
  }, {
    key: "goForward",
    value: function goForward() {
      this.relativeValue -= 20;
      this.transform();
      var modalContent = this.props.modal.context.modalContent;

      if (modalContent) {
        modalContent.goForward();
      }
    }
  }, {
    key: "transform",
    value: function transform() {
      this.modalNode.style.transform = "translateY(-".concat(this.relativeValue, "px)");
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props = this.props,
          children = _this$props.children,
          className = _this$props.className,
          lock = _this$props.lock,
          size = _this$props.size,
          zIndex = _this$props.zIndex,
          close = _this$props.close,
          modal = _this$props.modal,
          other = _objectWithoutProperties(_this$props, ["children", "className", "lock", "size", "zIndex", "close", "modal"]);

      return (/*#__PURE__*/React.createElement("div", _extends({
          className: cx("".concat("waui", "-modal"), _defineProperty({}, "".concat("waui", "-modal_").concat(size), size), className)
        }, other), /*#__PURE__*/React.createElement("div", {
          className: "".concat("waui", "-modal__backdrop"),
          style: {
            zIndex: zIndex || 3000
          }
        }), /*#__PURE__*/React.createElement("div", {
          className: "".concat("waui", "-modal__modal"),
          style: {
            zIndex: zIndex || 3000
          },
          onClick: this.handleModalClick
        }, /*#__PURE__*/React.createElement("div", {
          className: "".concat("waui", "-modal__modal-dialog"),
          ref: function ref(node) {
            return _this2.modalNode = node;
          }
        }, /*#__PURE__*/React.createElement("div", {
          className: "".concat("waui", "-modal__modal-content")
        }, children), /*#__PURE__*/React.createElement("div", {
          className: "".concat("waui", "-modal__modal-close"),
          onClick: function onClick() {
            return close();
          }
        }))))
      );
    }
  }]);

  return ModalContent;
}(Component);

ModalContent.childContextTypes = {
  modalContent: PropTypes.instanceOf(ModalContent)
};
ModalContent.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,
  lock: PropTypes.bool,
  size: PropTypes.string,
  zIndex: PropTypes.number,
  close: PropTypes.func,
  modal: PropTypes.object
};
export default ModalContent;
